# Table of Contents

- [getting-started-with-sap-leanix-architecture-and-road-map-planning](<./getting-started-with-sap-leanix-architecture-and-road-map-planning.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Getting Started with SAP LeanIX Architecture and Road Map Planning](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Activate SAP LeanIX Architecture and Road Map Planning](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Activate-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [First Steps To Realize Value With SAP LeanIX Architecture and Road Map Planning](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/First-Steps-To-Realize-Value-With-SAP-LeanIX-Architecture-and-Road-Map-Planning.md>)
  - [Pre-requisites](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Pre-requisites.md>)
  - [Step 0. Identify the Scope and Stakeholders for Your First Architecture and Road Map Planning Scenario](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Step-0.-Identify-the-Scope-and-Stakeholders-for-Your-First-Architecture-and-Road-Map-Planning-Scenario.md>)
  - [Step 1. Create Your First Project Roadmap With Milestones](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Step-1.-Create-Your-First-Project-Roadmap-With-Milestones.md>)
  - [Step 2. Define the Transformations necessary to implement a Project](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Step-2.-Define-the-Transformations-necessary-to-implement-a-Project.md>)
  - [Step 3. Visualize the Impact of Your Transformations and Compare](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Step-3.-Visualize-the-Impact-of-Your-Transformations-and-Compare.md>)
  - [Step 4. Implement the Optimal Project and Execute Transformations](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Step-4.-Implement-the-Optimal-Project-and-Execute-Transformations.md>)
  - [Next steps](<./Getting-Started-with-SAP-LeanIX-Architecture-and-Road-Map-Planning/Next-steps.md>)
